@@ -1,5 +1,5 @@
 /* libinfinity - a GObject-based infinote implementation
- * Copyright (C) 2007, 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2007-2010 Armin Burgmeier <armin@arbur.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,6 +20,7 @@
 #ifndef __INF_CERTIFICATE_CHAIN_H__
 #define __INF_CERTIFICATE_CHAIN_H__
 
+#include <unistd.h> /* Get ssize_t on MSVC, required by gnutls.h */
 #include <gnutls/gnutls.h>
 
 #include <glib-object.h>
@@ -31,7 +32,7 @@ G_BEGIN_DECLS
 /**
  * InfCertificateChain:
  *
- * #InfCertifiacteChain is an opaque data type. You should only access it
+ * #InfCertificateChain is an opaque data type. You should only access it
  * via the public API functions.
  */
 typedef struct _InfCertificateChain InfCertificateChain;
